.. _module-name:

!!!!!!
module
!!!!!!

.. meta::
   :keywords: module, xrst, module

.. index:: module, xrst, module

.. _module-title:

The xrst Module
###############

.. csv-table::
   :header:  "Name", "Title"
   :widths: auto

   "add_before_title", :ref:`add_before_title-title`
   "add_line_numbers", :ref:`add_line_numbers-title`
   "auto_file_dev", :ref:`auto_file_dev-title`
   "check_input_files", :ref:`check_input_files-title`
   "check_page_name", :ref:`check_page_name-title`
   "check_syntax_error", :ref:`check_syntax_error-title`
   "code_cmd_dev", :ref:`code_cmd_dev-title`
   "comment_cmd_dev", :ref:`comment_cmd_dev-title`
   "dir_cmd_dev", :ref:`dir_cmd_dev-title`
   "get_conf_dict", :ref:`get_conf_dict-title`
   "get_file_info", :ref:`get_file_info-title`
   "get_spell_checker", :ref:`get_spell_checker-title`
   "literal_cmd_dev", :ref:`literal_cmd_dev-title`
   "newline_indices", :ref:`newline_indices-title`
   "next_heading", :ref:`next_heading-title`
   "xrst.pattern", :ref:`xrst.pattern-title`
   "process_children", :ref:`process_children-title`
   "process_headings", :ref:`process_headings-title`
   "remove_indent", :ref:`remove_indent-title`
   "remove_line_numbers", :ref:`remove_line_numbers-title`
   "rename_group", :ref:`rename_group-title`
   "replace_spell", :ref:`replace_spell-title`
   "spell_cmd_dev", :ref:`spell_cmd_dev-title`
   "sphinx_label", :ref:`sphinx_label-title`
   "start_end_file", :ref:`start_end_file-title`
   "suspend_cmd_dev", :ref:`suspend_cmd_dev-title`
   "system_exit", :ref:`system_exit-title`
   "table_of_contents", :ref:`table_of_contents-title`
   "temporary_file", :ref:`temporary_file-title`
   "toc_cmd_dev", :ref:`toc_cmd_dev-title`

.. toctree::
   :maxdepth: 1
   :hidden:

   add_before_title
   add_line_numbers
   auto_file_dev
   check_input_files
   check_page_name
   check_syntax_error
   code_cmd_dev
   comment_cmd_dev
   dir_cmd_dev
   get_conf_dict
   get_file_info
   get_spell_checker
   literal_cmd_dev
   newline_indices
   next_heading
   xrst.pattern
   process_children
   process_headings
   remove_indent
   remove_line_numbers
   rename_group
   replace_spell
   spell_cmd_dev
   sphinx_label
   start_end_file
   suspend_cmd_dev
   system_exit
   table_of_contents
   temporary_file
   toc_cmd_dev
